#include <stddef.h>

// 插件信息结构体
typedef struct dpkgPlugin_s * dpkgPlugin;
// 插件列表结构体
typedef struct dpkgPlugins_s * dpkgPlugins;
// 钩子函数结构体
typedef struct dpkgPluginHooks_s * dpkgPluginHooks;
// deb信息结构体
typedef struct debts_s * debts;

typedef int (*plugin_init_func)(dpkgPlugin plugin); //加载插件时被调用
typedef int (*plugin_cleanup_func)(dpkgPlugin plugin); //清楚插件空间时被调用
typedef int (*plugin_pre_inst_func)(dpkgPlugin plugin, debts ts); //安装包之前被调用
typedef int (*plugin_post_inst_func)(dpkgPlugin plugin, debts ts); //安装包之后背调用
typedef int (*plugin_pre_uninst_func)(dpkgPlugin plugin, debts ts); //卸载包之前被调用
typedef int (*plugin_pre_info_func)(dpkgPlugin plugin, debts ts); //执行包配置文件之前被调用

//钩子函数结构体定义
struct dpkgPluginHooks_s{
	plugin_init_func	init;
	plugin_cleanup_func	cleanup;
	plugin_pre_inst_func	pre_inst;
    plugin_post_inst_func   post_inst;
	plugin_pre_uninst_func	pre_uninst;
    plugin_pre_info_func    pre_info;
};

// deb信息结构体定义
struct debts_s{
	char *deb_fullpath; //安装时的包绝对路径，卸载时的包名
    char **filepaths; //包文件路径列表
    int num_paths; //包文件路径列表实际长度
    int capacity; //包文件路径列表可用长度
    char **dpkg_info_filepaths;
    int dpkg_info_num_paths;
    int dpkg_info_capacity;
};

struct dpkgPlugin_s {
    char *name;
    void *handle;
    void *priv;
    dpkgPluginHooks hooks;
};

struct dpkgPlugins_s {
    dpkgPlugin *plugins;
    int count;
    debts ts;
};


// 给dpkgPlugins分配空间
dpkgPlugins dpkgpluginsNew(debts ts);
//添加插件
int dpkgpluginsAddPlugin(dpkgPlugins plugins);
// 执行包安装前钩子函数
int dpkgpluginsCallTsmInst(dpkgPlugins plugins, debts ts);
// 执行包安装后钩子函数
int dpkg_plugin_tsm_post_func(dpkgPlugins plugins, debts ts);
// 执行包卸载前钩子函数
int dpkgpluginsCallTsmUinst(dpkgPlugins plugins, debts ts);
// 执行包配置文件前钩子函数
int dpkg_plugin_info_pre_func(dpkgPlugins plugins, debts ts);
// 释放dpkgPlugins空间
dpkgPlugins dpkgpluginsFree(dpkgPlugins plugins);
